// BESResponseException.h

// This file is part of bes, A C++ back-end server implementation framework
// for the OPeNDAP Data Access Protocol.

// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
// Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact University Corporation for Atmospheric Research at
// 3080 Center Green Drive, Boulder, CO 80301
 
// (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
// Please read the full copyright statement in the file COPYRIGHT_UCAR.
//
// Authors:
//      pwest       Patrick West <pwest@ucar.edu>
//      jgarcia     Jose Garcia <jgarcia@ucar.edu>

#ifndef BESResponseException_h_
#define BESResponseException_h_ 1

#include "BESException.h"

/** @brief an exception object representing any exceptions thrown during the
 * building of a response object in a response handler
 *
 * A BESResponseException can be built by either passing the error string
 * to the constructor or by instantiating an empty object and using the
 * set_message method.
 *
 * To retreive the error string simpy use the get_message method.
 *
 * @see BESException
 * @see BESResponseHandler
 * @see BESResponseObject
 */
class BESResponseException : public BESException
{
protected:
      			BESResponseException() {}
public:
      			BESResponseException( const string &s,
			                      const string &file,
					      int line )
			    : BESException( s, file, line )
			{
			    set_context( "DataHandlerFailure" ) ;
			    set_return_code( BES_DATA_HANDLER_FAILURE ) ;
			}
      virtual		~BESResponseException() {}
};

#endif // BESResponseException_h_ 

